@@ -36,7 +36,7 @@ var optionsCmd = &cobra.Command{
 }
 
 // runOptions handles the executes the flow of "minikube options"
-func runOptions(cmd *cobra.Command, args []string) {
+func runOptions(cmd *cobra.Command, _ []string) {
 	out.String("The following options can be passed to any command:\n\n")
 	cmd.Root().PersistentFlags().VisitAll(func(flag *pflag.Flag) {
 		out.String(flagUsage(flag))
