@@ -147,7 +147,7 @@ You may select another namespace by using 'minikube service {{.service}} -n <nam
 				data = append(data, []string{svc.Namespace, svc.Name, servicePortNames, serviceURLs})
 
 				if serviceURLMode && !driver.NeedsPortForward(co.Config.Driver) {
-					out.String(fmt.Sprintf("%s\n", serviceURLs))
+					out.Stringf("%s\n", serviceURLs)
 				}
 			}
 			// check whether there are running pods for this service
@@ -229,7 +229,7 @@ func startKicServiceTunnel(services service.URLs, configName, driverName string)
 		service.PrintServiceList(os.Stdout, data)
 	} else {
 		for _, row := range data {
-			out.String(fmt.Sprintf("%s\n", row[3]))
+			out.Stringf("%s\n", row[3])
 		}
 	}
 
@@ -286,12 +286,12 @@ func openURLs(urls [][]string) {
 		_, err := url.Parse(u[3])
 		if err != nil {
 			klog.Warningf("failed to parse url %q: %v (will not open)", u[3], err)
-			out.String(fmt.Sprintf("%s\n", u))
+			out.Stringf("%s\n", u)
 			continue
 		}
 
 		if serviceURLMode {
-			out.String(fmt.Sprintf("%s\n", u))
+			out.Stringf("%s\n", u)
 			continue
 		}
 
