@@ -135,6 +135,10 @@ var (
 	//go:embed gcp-auth/*.tmpl gcp-auth/*.yaml
 	GcpAuthAssets embed.FS
 
+	// Volcano assets for volcano addon
+	//go:embed volcano/*.tmpl
+	VolcanoAssets embed.FS
+
 	// VolumeSnapshotsAssets assets for volumesnapshots addon
 	//go:embed volumesnapshots/*.tmpl volumesnapshots/*.yaml
 	VolumeSnapshotsAssets embed.FS
