@@ -25,6 +25,7 @@ import (
 	"github.com/blang/semver/v4"
 	"github.com/pkg/errors"
 	"k8s.io/klog/v2"
+
 	"k8s.io/minikube/pkg/minikube/bootstrapper/bsutil/ktmpl"
 	"k8s.io/minikube/pkg/minikube/cni"
 	"k8s.io/minikube/pkg/minikube/config"
@@ -37,7 +38,7 @@ import (
 // Container runtimes
 const remoteContainerRuntime = "remote"
 
-// GenerateKubeadmYAML generates the kubeadm.yaml file
+// GenerateKubeadmYAML generates the kubeadm.yaml file for primary control-plane node.
 func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Manager) ([]byte, error) {
 	k8s := cc.KubernetesConfig
 	version, err := util.ParseKubernetesVersion(k8s.KubernetesVersion)
@@ -52,11 +53,7 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 	}
 
 	// In case of no port assigned, use default
-	cp, err := config.PrimaryControlPlane(&cc)
-	if err != nil {
-		return nil, errors.Wrap(err, "getting control plane")
-	}
-	nodePort := cp.Port
+	nodePort := n.Port
 	if nodePort <= 0 {
 		nodePort = constants.APIServerPort
 	}
@@ -69,7 +66,7 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 		return nil, errors.Wrap(err, "getting cgroup driver")
 	}
 
-	componentOpts, err := createExtraComponentConfig(k8s.ExtraOptions, version, componentFeatureArgs, cp)
+	componentOpts, err := createExtraComponentConfig(k8s.ExtraOptions, version, componentFeatureArgs, n)
 	if err != nil {
 		return nil, errors.Wrap(err, "generating extra component config for kubeadm")
 	}
@@ -88,6 +85,16 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 
 	// ref: https://kubernetes.io/docs/reference/config-api/kubelet-config.v1beta1/#kubelet-config-k8s-io-v1beta1-KubeletConfiguration
 	kubeletConfigOpts := kubeletConfigOpts(k8s.ExtraOptions)
+	// container-runtime-endpoint kubelet flag was deprecated but corresponding containerRuntimeEndpoint kubelet config field is "required" but supported only from k8s v1.27
+	// ref: https://kubernetes.io/docs/reference/command-line-tools-reference/kubelet/#options
+	// ref: https://github.com/kubernetes/kubernetes/issues/118787
+	if version.GTE(semver.MustParse("1.27.0")) {
+		runtimeEndpoint := k8s.ExtraOptions.Get("container-runtime-endpoint", Kubelet)
+		if runtimeEndpoint == "" {
+			runtimeEndpoint = r.KubeletOptions()["container-runtime-endpoint"]
+		}
+		kubeletConfigOpts["containerRuntimeEndpoint"] = runtimeEndpoint
+	}
 	// set hairpin mode to hairpin-veth to achieve hairpin NAT, because promiscuous-bridge assumes the existence of a container bridge named cbr0
 	// ref: https://kubernetes.io/docs/tasks/debug/debug-application/debug-service/#a-pod-fails-to-reach-itself-via-the-service-ip
 	kubeletConfigOpts["hairpinMode"] = k8s.ExtraOptions.Get("hairpin-mode", Kubelet)
@@ -156,29 +163,29 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 		opts.ServiceCIDR = k8s.ServiceCIDR
 	}
 
-	configTmpl := ktmpl.V1Alpha3
-	// v1beta1 works in v1.13, but isn't required until v1.14.
-	if version.GTE(semver.MustParse("1.14.0-alpha.0")) {
-		configTmpl = ktmpl.V1Beta1
-	}
+	configTmpl := ktmpl.V1Beta1
 	// v1beta2 isn't required until v1.17.
 	if version.GTE(semver.MustParse("1.17.0")) {
 		configTmpl = ktmpl.V1Beta2
 	}
-
 	// v1beta3 isn't required until v1.23.
 	if version.GTE(semver.MustParse("1.23.0")) {
 		configTmpl = ktmpl.V1Beta3
 	}
+	// TODO: support v1beta4 kubeadm config when released - refs: https://kubernetes.io/docs/reference/config-api/kubeadm-config.v1beta4/ and https://github.com/kubernetes/kubeadm/issues/2890
+
 	if version.GTE(semver.MustParse("1.24.0-alpha.2")) {
 		opts.PrependCriSocketUnix = true
 	}
+
 	klog.Infof("kubeadm options: %+v", opts)
+
 	b := bytes.Buffer{}
 	if err := configTmpl.Execute(&b, opts); err != nil {
 		return nil, err
 	}
 	klog.Infof("kubeadm config:\n%s\n", b.String())
+
 	return b.Bytes(), nil
 }
 
