@@ -18,6 +18,116 @@ package constants
 
 var (
 	KubeadmImages = map[string]map[string]string{
+		"v1.30.4": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.29.8": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.28.13": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.31.0": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.31.0-rc.1": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.31.0-rc.0": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.27.16": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.30.3": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.29.7": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.28.12": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.31.0-beta.0": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.14-0",
+			"pause":           "3.10",
+		},
+		"v1.31.0-alpha.3": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.14-0",
+			"pause":           "3.10",
+		},
+		"v1.31.0-alpha.2": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.14-0",
+			"pause":           "3.10",
+		},
+		"v1.31.0-alpha.1": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.14-0",
+			"pause":           "3.10",
+		},
+		"v1.30.2": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.29.6": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.28.11": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.27.15": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.30.1": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.29.5": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.28.10": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
+		"v1.27.14": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.12-0",
+			"pause":           "3.9",
+		},
 		"v1.30.0": {
 			"coredns/coredns": "v1.11.1",
 			"etcd":            "3.5.12-0",
