@@ -1,5 +1,4 @@
 //go:build integration
-// +build integration
 
 /*
 Copyright 2016 The Kubernetes Authors All rights reserved.
@@ -50,6 +49,9 @@ var stderrAllow = []string{
 	`Your cgroup does not allow setting memory.`,
 	// progress bar output
 	`    > .*`,
+	// Warning of issues with specific Kubernetes versions
+	`Kubernetes .* has a known `,
+	`For more information, see`,
 }
 
 // stderrAllowRe combines rootCauses into a single regex
