@@ -149,11 +149,21 @@ func PodmanDriver() bool {
 	return strings.Contains(*startArgs, "--driver=podman") || strings.Contains(*startArgs, "--vm-driver=podman")
 }
 
+// Rootless returns whether or not this test is using the rootless KIC driver
+func RootlessDriver() bool {
+	return strings.Contains(*startArgs, "--rootless")
+}
+
 // KicDriver returns whether or not this test is using the docker or podman driver
 func KicDriver() bool {
 	return DockerDriver() || PodmanDriver()
 }
 
+// VMDriver checks if the driver is a VM
+func VMDriver() bool {
+	return !KicDriver() && !NoneDriver()
+}
+
 // ContainerRuntime returns the name of a specific container runtime if it was specified
 func ContainerRuntime() string {
 	flag := "--container-runtime="
@@ -162,7 +172,7 @@ func ContainerRuntime() string {
 			return strings.TrimPrefix(s, flag)
 		}
 	}
-	return constants.DefaultContainerRuntime
+	return constants.Docker
 }
 
 // arm64Platform returns true if running on arm64/* platform
@@ -171,9 +181,9 @@ func arm64Platform() bool {
 }
 
 // NeedsPortForward returns access to endpoints with this driver needs port forwarding
-// (Docker on non-Linux platforms requires ports to be forwarded to 127.0.0.1)
+// (Docker on non-Linux platforms and rootless KIC requires ports to be forwarded to 127.0.0.1)
 func NeedsPortForward() bool {
-	return KicDriver() && (runtime.GOOS == "windows" || runtime.GOOS == "darwin") || detect.IsMicrosoftWSL()
+	return KicDriver() && (runtime.GOOS == "windows" || runtime.GOOS == "darwin") || detect.IsMicrosoftWSL() || RootlessDriver()
 }
 
 // CanCleanup returns if cleanup is allowed
@@ -186,7 +196,7 @@ func Minutes(n int) time.Duration {
 	return time.Duration(*timeOutMultiplier) * time.Duration(n) * time.Minute
 }
 
-// Seconds will return timeout in minutes based on how slow the machine is
+// Seconds will return timeout in seconds based on how slow the machine is
 func Seconds(n int) time.Duration {
 	return time.Duration(*timeOutMultiplier) * time.Duration(n) * time.Second
 }
